﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Microsoft.Xaml.Interactivity;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Markup;

namespace _03_Blend.Behaviors
{
   [ContentProperty(Name = "Actions")]
   public class SectionHeaderClickBehavior : DependencyObject, IBehavior
   {      
      private DependencyObject associatedObject;

      /// <summary>
      /// Backing storage for Actions collection
      /// </summary>
      public static readonly DependencyProperty ActionsProperty =
			 DependencyProperty.Register("Actions", typeof(ActionCollection), typeof(SectionHeaderClickBehavior), new PropertyMetadata(null));

      /// <summary>
      /// Actions collection
      /// </summary>
      public ActionCollection Actions
      {
         get
         {
            ActionCollection actions = (ActionCollection)base.GetValue(ActionsProperty);
            if (actions == null)
            {
               actions = new ActionCollection();
               base.SetValue(ActionsProperty, actions);
            }

            return actions;
         }
      }

      #region IBehavior Members

      public Windows.UI.Xaml.DependencyObject AssociatedObject
      {
         get { return this.associatedObject; }
      }

      public void Attach(Windows.UI.Xaml.DependencyObject associatedObject)
      {
         Hub hub = associatedObject as Hub;
         if (hub == null) throw new InvalidOperationException("This behavior can be attached only to Hub control.");
         this.associatedObject = associatedObject;
         hub.SectionHeaderClick += this.OnSectionHeaderClicked;
      }     


      public void Detach()
      {
         Hub hub = this.AssociatedObject as Hub;
         if (hub != null)
         {
            hub.SectionHeaderClick -= this.OnSectionHeaderClicked;
            this.associatedObject = null;
         }

      }

      #endregion

		private void OnSectionHeaderClicked(object sender, HubSectionHeaderClickEventArgs e)
		{
			Interaction.ExecuteActions(this, this.Actions, e.Section.DataContext);			
		}
   }	
}
